BFGraph: CompressedSequence Class Reference

BFGraph

Public Member Functions
CompressedSequence Class Reference

## Public Member Functions
| CompressedSequence (const CompressedSequence &o)
CompressedSequence & | operator= (const CompressedSequence &o)
| CompressedSequence (CompressedSequence &&o)
CompressedSequence & | operator= (CompressedSequence &&o)
| CompressedSequence (const char *s)
| CompressedSequence (const string &s)
| CompressedSequence (const Kmer &km)
const char | operator[] (size_t index) const
void | clear ()
size_t | size () const
void | toString (char *s, const size_t offset, const size_t length) const
string | toString (const size_t offset, const size_t length) const
string | toString () const
void | toString (char *s) const
Kmer | getKmer (size_t offset) const
bool | compareKmer (const size_t offset, const Kmer &km) const
void | setSequence (const CompressedSequence &o, const size_t start, const size_t length, const size_t offset=0, const bool reversed=false)
void | setSequence (const char *s, const size_t length, const size_t offset=0, const bool reversed=false)
void | setSequence (const string &s, const size_t length, const size_t offset=0, const bool reversed=false)
void | setSequence (const Kmer &km, const size_t length, const size_t offset=0, const bool reversed=false)
void | reserveLength (const size_t new_length)
CompressedSequence | rev () const
size_t | jump (const char *s, const size_t i, int pos, const bool reversed) const
size_t | bw_jump (const char *s, const size_t i, int pos, const bool reversed) const
int64_t | findKmer (const Kmer &km) const
bool | isShort () const

The documentation for this class was generated from the following files:

- src/CompressedSequence.hpp
- src/CompressedSequence.cpp